Kotti is a user-friendly, light-weight and extensible `web content
management system`_.  It is licensed under a `BSD-like license
<http://repoze.org/license.html>`_

Features
========

- **User-friendly**: a simple edit interface hides advanced
  functionality from less experienced users

- **WYSIWYG editor**: includes a rich text editor that lets you edit
  content like in office applications

- **Security**: advanced user, groups and user roles management; uses
  `access control lists`_ (ACL) to control access to different parts
  of the site

- **Templating**: extend Kotti with your own look & feel with very
  little programming required

- **Customizable**: Many aspects of Kotti are configured through a
  simple INI file

- **Add-ons**: a plug-in system allows third party software to greatly
  extend Kotti

- **Pluggable authentication**: allows authentication of users through
  LDAP or other existing user databases

- **Open**: built on top of well-documented, open source components,
  such as Python_, Pyramid_ and SQLAlchemy_

- **Tested**: `continuous testing`_ with a test coverage of 100%
  guarantees Kotti's stability

Documentation
=============

`Click here to access Kotti's documentation
<http://kotti.readthedocs.org/>`_

Try it out
==========

You can try out Kotti on `Kotti's demo site`_.

Thanks
======

Kotti thanks the `University of Coimbra`_ for their involvement and
support in the initial phase of the project.


.. _web content management system: http://en.wikipedia.org/wiki/Web_content_management_system
.. _access control lists: http://en.wikipedia.org/wiki/Access_control_list
.. _Python: http://www.python.org/
.. _Pyramid: http://docs.pylonsproject.org/projects/pyramid/dev/
.. _SQLAlchemy: http://www.sqlalchemy.org/
.. _continuous testing: http://jenkins.danielnouri.org/job/Kotti/
.. _Kotti's demo site: http://kottidemo.danielnouri.org/
.. _University of Coimbra: http://uc.pt/
